@@ -4,3 +4,5 @@ resultado = Calculadora(22,2,1)
 
 print(resultado.sumatoria())
 
+def obs():
+    print("Holaaaaa")
